@@ -257,7 +257,7 @@ class Mailbox(models.Model):
         msg = Message()
         msg.mailbox = self
         if 'subject' in message:
-            msg.subject = convert_header_to_unicode(message['subject'][0:255])
+            msg.subject = convert_header_to_unicode(message['subject'])[0:255]
         if 'message-id' in message:
             msg.message_id = message['message-id'][0:255]
         if 'from' in message:
